@@ -4,7 +4,7 @@
 /* Copyright 1999,2000,2001 BrightStation PLC
  * Copyright 2001,2005 James Aylett
  * Copyright 2001,2002 Ananova Ltd
- * Copyright 2002,2003,2004,2005,2006,2007,2008,2009,2010,2011,2012,2013,2014,2015,2017,2018 Olly Betts
+ * Copyright 2002-2022 Olly Betts
  * Copyright 2009 Frank J Bruzzaniti
  * Copyright 2012 Mihai Bivol
  *
@@ -71,6 +71,7 @@ static off_t max_size = 0;
 static std::string pretty_max_size;
 static bool verbose = false;
 static double sleep_before_opendir = 0;
+static bool date_terms = true;
 
 static string root;
 static string url_start_path;
@@ -369,6 +370,8 @@ main(int argc, char **argv)
     enum {
 	OPT_OPENDIR_SLEEP = 256,
 	OPT_SAMPLE,
+	OPT_DATE_TERMS,
+	OPT_NO_DATE_TERMS,
 	OPT_READ_FILTERS
     };
     constexpr auto NO_ARG = no_argument;
@@ -400,6 +403,8 @@ main(int argc, char **argv)
 	{ "retry-failed",	NO_ARG,		NULL, 'R' },
 	{ "opendir-sleep",	REQ_ARG,	NULL, OPT_OPENDIR_SLEEP },
 	{ "track-ctime",	NO_ARG,		NULL, 'C' },
+	{ "date-terms",		NO_ARG,		NULL, OPT_DATE_TERMS },
+	{ "no-date-terms",	NO_ARG,		NULL, OPT_NO_DATE_TERMS },
 	{ 0, 0, NULL, 0 }
     };
 
@@ -483,6 +488,11 @@ main(int argc, char **argv)
 "                            on Microsoft DFS shares.\n"
 "  -C, --track-ctime         track each file's ctime so we can detect changes\n"
 "                            to ownership or permissions.\n"
+"      --date-terms          ignored for forward compatibility with Omega\n"
+"                            1.5.x.\n"
+"      --no-date-terms       don't index D, M and Y prefixed terms to support\n"
+"                            date range filtering using terms (we now recommend\n"
+"                            using a value slot for this instead).\n"
 "  -v, --verbose             show more information about what is happening\n"
 "      --overwrite           create the database anew (the default is to update\n"
 "                            if the database already exists)" << endl;
@@ -666,6 +676,12 @@ main(int argc, char **argv)
 	case 'C':
 	    use_ctime = true;
 	    break;
+	case OPT_DATE_TERMS:
+	    // Ignored for compatibility with Omega 1.5.0.
+	    break;
+	case OPT_NO_DATE_TERMS:
+	    date_terms = false;
+	    break;
 	case 'G': {
 	    char * s = strrchr(optarg, ':');
 	    if (s == NULL) {
@@ -757,7 +773,7 @@ main(int argc, char **argv)
 
     root = argv[optind];
     if (root.empty()) {
-	cerr << PROG_NAME": start directory can not be empty." << endl;
+	cerr << PROG_NAME": start directory can not be empty string." << endl;
 	return 1;
     }
     if (!endswith(root, '/')) {
@@ -789,7 +805,7 @@ main(int argc, char **argv)
 		   sample_size, title_size, max_ext_len,
 		   overwrite, retry_failed, delete_removed_documents, verbose,
 		   use_ctime, spelling, ignore_exclusions,
-		   description_as_sample);
+		   description_as_sample, date_terms);
 	index_directory(root, baseurl, depth_limit, mime_map);
 	index_handle_deletion();
 	index_commit();
