@@ -1023,6 +1023,7 @@ CMD_setrelevant,
 CMD_slice,
 CMD_snippet,
 CMD_sort,
+CMD_sortableunserialise,
 CMD_split,
 CMD_stoplist,
 CMD_sub,
@@ -1047,6 +1048,8 @@ CMD_unstem,
 CMD_upper,
 CMD_url,
 CMD_value,
+CMD_valuelowerbound,
+CMD_valueupperbound,
 CMD_version,
 CMD_weight,
 CMD_MACRO // special tag for macro evaluation
@@ -1168,6 +1171,8 @@ T(setrelevant,	   1, 1, N, Q), // set rset
 T(slice,	   2, 2, N, 0), // slice a list using a second list
 T(snippet,	   1, 2, N, M), // generate snippet from text
 T(sort,		   1, 2, N, 0), // alpha sort a list
+T(sortableunserialise,
+		   1, 1, N, 0), // decode with Xapian::sortable_unserialise
 T(split,	   1, 2, N, 0), // split a string to give a list
 T(stoplist,	   0, 0, N, Q), // return list of stopped terms
 T(sub,		   2, 2, N, 0), // subtract
@@ -1195,6 +1200,8 @@ T(unstem,	   1, 1, N, Q), // return list of terms from the parsed query
 T(upper,	   1, 1, N, 0), // convert string to upper case
 T(url,		   1, 1, N, 0), // url encode argument
 T(value,	   1, 2, N, 0), // return document value
+T(valuelowerbound, 1, 1, N, 0), // return value slot lower bound
+T(valueupperbound, 1, 1, N, 0), // return value slot upper bound
 T(version,	   0, 0, N, 0), // omega version string
 T(weight,	   0, 0, N, 0), // weight of the current hit
 { NULL,{0,	   0, 0, 0, 0}}
@@ -2278,6 +2285,11 @@ eval(const string& fmt, vector<string>& param)
 	    case CMD_sort:
 		omegascript_sort(args, value);
 		break;
+	    case CMD_sortableunserialise:
+		// FIXME: This uses printf %f - maybe we want more than 6
+		// decimal places in some cases though...
+		value = double_to_string(Xapian::sortable_unserialise(args[0]));
+		break;
 	    case CMD_split: {
 		string split;
 		if (args.size() == 1) {
@@ -2550,6 +2562,16 @@ eval(const string& fmt, vector<string>& param)
 		value = db.get_document(id).get_value(value_no);
 		break;
 	    }
+	    case CMD_valuelowerbound: {
+		Xapian::valueno slot = string_to_int(args[0]);
+		value = db.get_value_lower_bound(slot);
+		break;
+	    }
+	    case CMD_valueupperbound: {
+		Xapian::valueno slot = string_to_int(args[0]);
+		value = db.get_value_upper_bound(slot);
+		break;
+	    }
 	    case CMD_version:
 		value = PACKAGE_STRING;
 		break;
